# 5장 그레이들 활용하기

## 리스트 5-1
```
package com.tuyano.fx;

import javafx.application.Application;
import static javafx.application.Application.launch;
import javafx.fxml.FXMLLoader;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.stage.Stage;

public class App extends Application {

    @Override
    public void start(Stage stage) throws Exception {
        Parent root = FXMLLoader.load(getClass()
            .getResource("/fxml/Scene.fxml"));

        Scene scene = new Scene(root);
        stage.setTitle("JavaFX App");
        stage.setScene(scene);
        stage.show();
    }

    public static void main(String[] args) {
        launch(args);
    }

}
```

## 리스트 5-2
```
package com.tuyano.fx;

import java.net.URL;
import java.util.ResourceBundle;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.Label;
import javafx.scene.control.TextField;

public class FXMLController implements Initializable {

    @FXML
    private Label label;
    @FXML
    private TextField field;

    @FXML
    private void handleButtonAction(ActionEvent event) {
        label.setText("Hello, " + field.getText() + "!");
    }

    @Override
    public void initialize(URL url, ResourceBundle rb) {}
}
```

## 리스트 5-3
```
<?xml version="1.0" encoding="UTF-8"?>

<?import java.lang.*?>
<?import java.util.*?>
<?import javafx.scene.*?>
<?import javafx.scene.control.*?>
<?import javafx.scene.layout.*?>

<AnchorPane id="AnchorPane" 
    prefHeight="166.0" prefWidth="320"
    xmlns:fx="http://javafx.com/fxml/1"
    xmlns="http://javafx.com/javafx/8"
    fx:controller="com.tuyano.fx.FXMLController">

    <children>
        <Label fx:id="label" layoutX="16.0" layoutY="14.0"
            minHeight="16" minWidth="100"
            prefHeight="31.0" prefWidth="289.0"
            text="your name:" />
        <Button fx:id="button"
            layoutX="128.0" layoutY="102.0"
            onAction="#handleButtonAction"
            text="Click Me!" />
        <TextField fx:id="field" layoutX="16.0" layoutY="45.0"
            prefHeight="25.0" prefWidth="289.0" />
    </children>
</AnchorPane>
```

## 리스트 5-4
```
apply plugin: 'java'
apply plugin: 'javafx-gradle-plugin'

buildscript {
    repositories {
        mavenCentral()
    }
    dependencies {
        classpath group:'de.dynamicfiles.projects.gradle.plugins',
            name:'javafx-gradle-plugin', version:'8.8.2'
    }
}

jfx {
    mainClass = 'com.tuyano.fx.App'
    vendor = 'tuyano project'
}
```

## 리스트 5-5
```
<html>
<head>
    <title>Sample Index</title>
</head>
<body>
    <h1>Hello World!</h1>
    <%= new java.util.Date().toString() %>
</body>
</html>
```

## 리스트 5-6
```
package com.tuyano.web;

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@WebServlet("/sample")
public class MyServlet extends HttpServlet {
    private static final long serialVersionUID = 1L;

    @Override
    protected void doGet(HttpServletRequest request,
            HttpServletResponse response)
            throws ServletException, IOException {
        response.setContentType("text/html;charset=UTF-8");
        PrintWriter out = response.getWriter();
        out.println("<html><head></head>");
        out.println("<body><h1>Hello!</h1>");
        out.println("<p>this is sample servlet.</p>");
        out.println("</body></html>");
    }
}
```

## 리스트 5-7
```
<?xml version="1.0" encoding="UTF-8"?>
<web-app 
    xmlns="http://xmlns.jcp.org/xml/ns/javaee"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://xmlns.jcp.org/xml/ns/javaee
        http://xmlns.jcp.org/xml/ns/javaee/web-app_3_1.xsd"
    version="3.1">

    <display-name>Web Application</display-name>

    <servlet>
        <servlet-name>serv</servlet-name>
        <servlet-class>com.tuyano.web.MyServlet</servlet-class>
    </servlet>
    <servlet-mapping>
        <servlet-name>serv</servlet-name>
        <url-pattern>/serv</url-pattern>
    </servlet-mapping>
</web-app>
```

## 리스트 5-8
```
apply plugin: 'java'
apply plugin: 'war'

repositories {
    mavenCentral()
}

dependencies {
    testCompile group:'junit', name:'junit', version:'4.12'
    compile group:'javax.servlet', name:'javax.servlet-api', version:'3.1.0'
}
```

## 리스트 5-9
```
apply plugin: 'java'
apply plugin: 'war'
apply plugin: 'org.akhikhl.gretty'

buildscript {
    repositories {
        mavenCentral()
    }
    dependencies {
        classpath group:'org.akhikhl.gretty', name:'gretty', version:'+'
    }
}

repositories {
    mavenCentral()
}

dependencies {
    testCompile group:'junit', name:'junit', version:'4.12'
    compile group:'javax.servlet', name:'javax.servlet-api', version:'3.1.0'
}
```

## 리스트 5-10
```
package com.tuyano.rest;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

@Path("myresource")
public class MyResource {

    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String getIt() {
        return "{id:1, message:\"this is RESTful app sample!\"}";
    }
}
```

## 리스트 5-11
```
<?xml version="1.0" encoding="UTF-8"?>
<web-app xmlns="http://xmlns.jcp.org/xml/ns/javaee"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://xmlns.jcp.org/xml/ns/javaee
        http://xmlns.jcp.org/xml/ns/javaee/web-app_3_1.xsd"
    version="3.1">

    <servlet>
        <servlet-name>Jersey Web Application</servlet-name>
        <servlet-class>org.glassfish.jersey.servlet.ServletContainer</servlet-class>
        <init-param>
            <param-name>jersey.config.server.provider.packages</param-name>
            <param-value>com.tuyano.rest</param-value>
        </init-param>
        <load-on-startup>1</load-on-startup>
    </servlet>

    <servlet-mapping>
        <servlet-name>Jersey Web Application</servlet-name>
        <url-pattern>/webapi/*</url-pattern>
    </servlet-mapping>

</web-app>
```

## 리스트 5-12
```
apply plugin: 'java'
apply plugin: 'war'
apply plugin: 'org.akhikhl.gretty'

buildscript {
    repositories {
        mavenCentral()
    }
    dependencies {
        classpath group:'org.akhikhl.gretty', name:'gretty', version:'+'
    }
}

repositories {
    mavenCentral()
}

dependencies {
    testCompile group:'junit', name:'junit', version:'4.12'
    compile group:'javax.servlet', name:'javax.servlet-api', version:'3.1.0'
    compile group:'org.glassfish.jersey', name:'jersey-bom', version:'2.24.1'
    compile group:'org.glassfish.jersey.containers',
        name:'jersey-container-servlet-core', version:'2.24.1'
}
```

## 리스트 5-13
```
package com.tuyano.spring;

import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;

@Configuration
@EnableAutoConfiguration
@ComponentScan
public class App implements CommandLineRunner {

    @Override
    public void run(String... args) {
        System.out.println("run!");
    }

    public static void main(String[] args) throws Exception {
        SpringApplication.run(App.class, args);
    }
}
```

## 리스트 5-14
```
package com.tuyano.spring;

import java.util.Date;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
public class HeloController {

    @RequestMapping("/")
    public String index(){
        return "Welcome to Spring Boot Application!! (" +
        new Date().toString() + ")";
    }
}
```

## 리스트 5-15
```
apply plugin: 'java'
apply plugin: 'org.springframework.boot'

buildscript {
    repositories {
        jcenter()
        maven { url "http://repo.spring.io/snapshot" }
        maven { url "http://repo.spring.io/milestone" }
    }
    dependencies {
        classpath group:"org.springframework.boot", name:"spring-boot-gradle-plugin", version:"1.+"
    }
}

jar {
    baseName = 'gradle-spring-app'
    version =  '0.0.1-SNAPSHOT'
}

repositories {
    jcenter()
    maven { url "http://repo.spring.io/snapshot" }
    maven { url "http://repo.spring.io/milestone" }
}

dependencies {
    compile group:"org.springframework.boot", name:"spring-boot-starter-web", version:"1.+"
    testCompile group:"org.springframework.boot", name:"spring-boot-starter-test", version:"1.+"
}
```

## 리스트 5-16
```
import java.util.Date;

class App {
    
    static main(args){
        println '===================='
        println 'Welcome to Groovy!'
        println new Date()
        println '===================='
    }

}
```

## 리스트 5-17
```
apply plugin: 'groovy'
apply plugin: 'application'

mainClassName='App'

repositories {
    mavenCentral()
}

dependencies {
    compile group:'org.codehaus.groovy', name:'groovy-all', version:'2.4.7'
    testCompile group:'junit', name:'junit', version:'4.12'
}
```

## 리스트 5-18――index.gsp
```
<% def msg = "This is Groovy Web application!" %>
<html>
<head><title>GSP Page</title></head>
<body>
    <h1>Hello</h1>
    <p>${msg}</p>
    <p><%=new java.util.Date() %></p>
</body>
</html>
```

## 리스트 5-19――helo.groovy
```
html.html {
    head {
        title 'Groovlet'
    }
    body {
        h1 'Hello!'
        p 'Welcome to the Groovlet world!'
    }
}
```

## 리스트 5-20――web.xml
```
<?xml version="1.0" encoding="UTF-8"?>
<web-app 
    xmlns="http://xmlns.jcp.org/xml/ns/javaee"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://xmlns.jcp.org/xml/ns/javaee
        http://xmlns.jcp.org/xml/ns/javaee/web-app_3_1.xsd"
    version="3.1">

    <display-name>Web Application</display-name>

    <welcome-file-list>
        <welcome-file>index.html</welcome-file>
        <welcome-file>index.gsp</welcome-file>
    </welcome-file-list>

    <servlet>
        <servlet-name>Groovy</servlet-name>
        <servlet-class>groovy.servlet.GroovyServlet</servlet-class>
    </servlet>

    <servlet-mapping>
        <servlet-name>Groovy</servlet-name>
        <url-pattern>*.groovy</url-pattern>
    </servlet-mapping>

    <servlet>
        <servlet-name>GroovyTemplate</servlet-name>
        <servlet-class>groovy.servlet.TemplateServlet</servlet-class>
    </servlet>

    <servlet-mapping>
        <servlet-name>GroovyTemplate</servlet-name>
        <url-pattern>*.gsp</url-pattern>
    </servlet-mapping>

</web-app>
```

## 리스트 5-20――build.gradle
```
apply plugin: 'groovy'
apply plugin: 'war'
apply plugin: 'org.akhikhl.gretty'

buildscript {
    repositories {
        mavenCentral()
    }
    dependencies {
        classpath group:'org.akhikhl.gretty', name:'gretty', version:'+'
    }
}

repositories {
    mavenCentral()
}

dependencies {
    compile group:'org.codehaus.groovy', name:'groovy-all', version:'2.4.7'
    testCompile group:'junit', name:'junit', version:'4.12'
    compile group:'javax.servlet', name:'javax.servlet-api', version:'3.1.0'
}
```

## 리스트 5-21
```
task doAnt {
    doLast {
        ant.echo "this is ant task!"
    }
}
```

## 리스트 5-22
```
task doAnt {
    doLast {
        ant.delete dir:'myfolder'
        ant.mkdir dir:'myfolder'
        ant.copy file:'build.gradle', todir:'myfolder'
        ant.mkdir dir:'myfolder/my_classes'
        ant.javac srcdir:'src/main/java', destdir:'myfolder/my_classes',
            includeAntRuntime:false
        ant.echo "compiled java source files."
    }
}
```

## 리스트 5-23
```
<project>
    <target name="myTarget">
        <echo>load build.xml....</echo>
        <delete dir="my_folder" />
        <mkdir dir="my_folder" />
        <mkdir dir="my_folder/my_classes" />
        <copy file="build.gradle" todir="my_folder" />
        <javac srcdir="src/main/java" destdir="my_folder/my_classes"
            includeAntRuntime="false" />
        <echo>compiled!</echo>
    </target>
</project>
```

## 리스트 5-24
```
ant.importBuild 'build.xml'

task doByXml(dependsOn: myTarget) {
    doLast {
        println '* finished build.xml. *'
    }
}
```

## 리스트 5-25
```
task doAnt {
    doLast {
        def path = ant.path {
            fileset(dir: '.') {
                include(name: 'gradle*.*')
            }
        }
        ant.echo path.list().size() + " files."
        path.list().each {
            println ":" + it
        }
    }
}
```

## 리스트 5-26
```
task doZip {
    doLast {
        def fldr = 'archive_folder'
        ant.delete dir:fldr
        ant.mkdir dir:fldr
        ant.zip(destfile: fldr + '/archive.zip') {
            fileset(dir: '.') {
                include(name: '*gradle*')
            }
        }
        ant.echo "archived."
    }
}
```